@@ -1,77 +1,67 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "customdebugsettingspage.h"
 #include "configurecustomsettingdialog.h"
 #include "kdebugsettingsutil.h"
-#include <KLocalizedString>
 #include <KListWidgetSearchLine>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <QListWidget>
 #include <QLabel>
-#include <QPushButton>
+#include <QListWidget>
+#include <QMenu>
 #include <QPointer>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 CustomDebugSettingsPage::CustomDebugSettingsPage(QWidget *parent)
     : QWidget(parent)
+    , mListWidget(new QListWidget(this))
+    , mAddRule(new QPushButton(i18n("Add..."), this))
+    , mEditRule(new QPushButton(i18n("Edit..."), this))
+    , mRemoveRule(new QPushButton(i18n("Remove..."), this))
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QLabel *lab = new QLabel(i18n("Rules:"), this);
+    auto lab = new QLabel(i18n("Rules:"), this);
     lab->setObjectName(QStringLiteral("custom_label"));
     mainLayout->addWidget(lab);
 
-    auto *horizontalLayout = new QHBoxLayout;
+    auto horizontalLayout = new QHBoxLayout;
     horizontalLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addLayout(horizontalLayout);
 
-    auto *vbox = new QVBoxLayout;
+    auto vbox = new QVBoxLayout;
     horizontalLayout->addLayout(vbox);
 
-    mListWidget = new QListWidget(this);
     mListWidget->setObjectName(QStringLiteral("custom_listwidget"));
-    mListWidget->setSelectionMode(QAbstractItemView::MultiSelection);
+    mListWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
+    mListWidget->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(mListWidget, &QListWidget::itemSelectionChanged, this, &CustomDebugSettingsPage::updateButtons);
     connect(mListWidget, &QListWidget::itemDoubleClicked, this, &CustomDebugSettingsPage::slotEditRule);
-    auto *searchLine = new KListWidgetSearchLine(this, mListWidget);
+    connect(mListWidget, &QListWidget::customContextMenuRequested, this, &CustomDebugSettingsPage::slotCustomContextMenu);
+    auto searchLine = new KListWidgetSearchLine(this, mListWidget);
     searchLine->setObjectName(QStringLiteral("searchline"));
     searchLine->setPlaceholderText(i18n("Search..."));
     vbox->addWidget(searchLine);
     vbox->addWidget(mListWidget);
 
-    auto *buttonLayout = new QVBoxLayout;
+    auto buttonLayout = new QVBoxLayout;
     horizontalLayout->addLayout(buttonLayout);
 
-    mAddRule = new QPushButton(i18n("Add..."), this);
     mAddRule->setObjectName(QStringLiteral("add_rule"));
     buttonLayout->addWidget(mAddRule);
     connect(mAddRule, &QAbstractButton::clicked, this, &CustomDebugSettingsPage::slotAddRule);
 
-    mEditRule = new QPushButton(i18n("Edit..."), this);
     mEditRule->setObjectName(QStringLiteral("edit_rule"));
     buttonLayout->addWidget(mEditRule);
     connect(mEditRule, &QAbstractButton::clicked, this, &CustomDebugSettingsPage::slotEditRule);
 
-    mRemoveRule = new QPushButton(i18n("Remove..."), this);
     mRemoveRule->setObjectName(QStringLiteral("remove_rule"));
     buttonLayout->addWidget(mRemoveRule);
     buttonLayout->addStretch();
@@ -83,6 +73,21 @@ CustomDebugSettingsPage::~CustomDebugSettingsPage()
 {
 }
 
+void CustomDebugSettingsPage::slotCustomContextMenu(const QPoint &pos)
+{
+    QMenu menu(this);
+    const int selectedItemCount{mListWidget->selectedItems().count()};
+    menu.addAction(i18n("Add Rule..."), this, &CustomDebugSettingsPage::slotAddRule);
+    if (selectedItemCount == 1) {
+        menu.addAction(QIcon::fromTheme(QStringLiteral("edit")), i18n("Edit Rule"), this, &CustomDebugSettingsPage::slotEditRule);
+    }
+    if (selectedItemCount > 0) {
+        menu.addSeparator();
+        menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove Rule"), this, &CustomDebugSettingsPage::slotRemoveRules);
+    }
+    menu.exec(mListWidget->viewport()->mapToGlobal(pos));
+}
+
 void CustomDebugSettingsPage::updateButtons()
 {
     mEditRule->setEnabled(mListWidget->selectedItems().count() == 1);
