@@ -1,30 +1,20 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "kdebugsettingsutil.h"
 #include "kdebugsettings_debug.h"
+#include <KLocalizedString>
+#include <QDir>
 #include <QFile>
 #include <QRegularExpression>
-#include <KLocalizedString>
 #include <QStandardPaths>
-#include <QDir>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QTextCodec>
+#endif
 
 RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line, const QString &filename)
 {
@@ -41,14 +31,8 @@ RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line, const QStri
     line = line.simplified();
     const int space = line.indexOf(QLatin1Char(' '));
     if (space == -1) {
-        qCWarning(KDEBUGSETTINGS_LOG) << "Invalid categories file. Missing space. Syntax is logname<space>description + optional element. Line: "
-                                      << line << " from file:" << filename
-                                 #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                                      << endl
-                                 #else
-                                      << Qt::endl
-                                 #endif
-                                         ;
+        qCWarning(KDEBUGSETTINGS_LOG) << "Invalid categories file. Missing space. Syntax is logname<space>description + optional element. Line: " << line
+                                      << " from file:" << filename << Qt::endl;
         return category;
     }
 
@@ -70,7 +54,11 @@ RenameCategory::List KDebugSettingsUtil::readRenameCategories(const QString &fil
     } else {
         QString data;
         QTextStream ts(&file);
-        ts.setCodec("ISO-8859-1");
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        ts.setCodec(QTextCodec::codecForName("ISO-8859-1"));
+#else
+        ts.setEncoding(QStringConverter::Encoding::Latin1);
+#endif
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
             const RenameCategory category = parseRenameCategory(data, filename);
@@ -97,14 +85,8 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
     line = line.simplified();
     const int space = line.indexOf(QLatin1Char(' '));
     if (space == -1) {
-        qCWarning(KDEBUGSETTINGS_LOG) << "Invalid categories file. Missing space. Syntax is logname<space>description + optional element. Line: "
-                                      << line << " from file:" << filename
-                                 #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                                      << endl
-                                 #else
-                                      << Qt::endl
-                                 #endif
-                                         ;
+        qCWarning(KDEBUGSETTINGS_LOG) << "Invalid categories file. Missing space. Syntax is logname<space>description + optional element. Line: " << line
+                                      << " from file:" << filename << Qt::endl;
         return category;
     }
     QString logName;
@@ -114,7 +96,7 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
 
 #if 1
 
-    //TODO create an unique regularexpression
+    // TODO create an unique regularexpression
 
     static const QRegularExpression regularExpressionUser(QStringLiteral("^([\\w._-]+)\\s*(.*)$"));
     QRegularExpressionMatch match = regularExpressionUser.match(line);
@@ -124,7 +106,8 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
     }
 
     bool newFormatFound = false;
-    static const QRegularExpression regularExpressionDefaultSeverityNewFormat(QStringLiteral("^(.*)\\s+DEFAULT_SEVERITY\\s+\\[(DEBUG|INFO|WARNING|CRITICAL)\\](?:\\s+(.*))?"));
+    static const QRegularExpression regularExpressionDefaultSeverityNewFormat(
+        QStringLiteral("^(.*)\\s+DEFAULT_SEVERITY\\s+\\[(DEBUG|INFO|WARNING|CRITICAL)\\](?:\\s+(.*))?"));
     QRegularExpressionMatch match3 = regularExpressionDefaultSeverityNewFormat.match(description);
     QString defaultSeverityCaptured;
     QString potentialIdentifier;
@@ -136,8 +119,8 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
         if (!descriptionCaptured.isEmpty() && !defaultSeverityCaptured.isEmpty()) {
             description = descriptionCaptured;
             defaultSeverity = defaultSeverityCaptured;
-            //qDebug() << " match.captured(1);" << descriptionCaptured;
-            //qDebug() << " match.captured(2);" << defaultCategoryCaptured;
+            // qDebug() << " match.captured(1);" << descriptionCaptured;
+            // qDebug() << " match.captured(2);" << defaultCategoryCaptured;
         }
     }
 
@@ -151,8 +134,8 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
             if (!descriptionCaptured.isEmpty() && !identifierCaptured.isEmpty()) {
                 description = descriptionCaptured;
                 identifier = identifierCaptured;
-                //qDebug() << " match.captured(1);" << descriptionCaptured;
-                //qDebug() << " match.captured(2);" << identifierCaptured;
+                // qDebug() << " match.captured(1);" << descriptionCaptured;
+                // qDebug() << " match.captured(2);" << identifierCaptured;
             }
         }
     } else {
@@ -168,7 +151,7 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
     }
 
     if (!newFormatFound) {
-        //Old format.
+        // Old format.
         static const QRegularExpression regularExpressionDefaultSeverityOldFormat(QStringLiteral("^(.*)\\s+\\[(DEBUG|INFO|WARNING|CRITICAL)\\]"));
         QRegularExpressionMatch match2 = regularExpressionDefaultSeverityOldFormat.match(description);
         if (match2.hasMatch()) {
@@ -177,8 +160,8 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
             if (!descriptionCaptured.isEmpty() && !defaultSeverityCaptured.isEmpty()) {
                 description = descriptionCaptured;
                 defaultSeverity = defaultSeverityCaptured;
-                //qDebug() << " match.captured(1);" << descriptionCaptured;
-                //qDebug() << " match.captured(2);" << defaultCategoryCaptured;
+                // qDebug() << " match.captured(1);" << descriptionCaptured;
+                // qDebug() << " match.captured(2);" << defaultCategoryCaptured;
                 qCWarning(KDEBUGSETTINGS_LOG) << "In this file: " << filename << " this line " << line << " still use old format. We need to port it";
             }
         } else {
@@ -213,7 +196,11 @@ KdeLoggingCategory::List KDebugSettingsUtil::readLoggingCategoriesForInserting(c
     } else {
         QString data;
         QTextStream ts(&file);
-        ts.setCodec("ISO-8859-1");
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        ts.setCodec(QTextCodec::codecForName("ISO-8859-1"));
+#else
+        ts.setEncoding(QStringConverter::Encoding::Latin1);
+#endif
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
             const KdeLoggingCategory category = parseLineKdeLoggingCategory(data, filename);
@@ -224,7 +211,8 @@ KdeLoggingCategory::List KDebugSettingsUtil::readLoggingCategoriesForInserting(c
                         needToAppend = false;
                         break;
                     } else if (cat.categoryName == category.categoryName) {
-                        qCWarning(KDEBUGSETTINGS_LOG) << "Duplicate categories, it's a bug. Please verify: categorie:" << cat.categoryName << " filename : "<< filename;
+                        qCWarning(KDEBUGSETTINGS_LOG) << "Duplicate categories, it's a bug. Please verify: category:" << cat.categoryName
+                                                      << " filename : " << filename;
                         needToAppend = false;
                     }
                 }
@@ -246,7 +234,11 @@ void KDebugSettingsUtil::readLoggingCategories(const QString &filename, KdeLoggi
     } else {
         QString data;
         QTextStream ts(&file);
-        ts.setCodec("ISO-8859-1");
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        ts.setCodec(QTextCodec::codecForName("ISO-8859-1"));
+#else
+        ts.setEncoding(QStringConverter::Encoding::Latin1);
+#endif
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
             const KdeLoggingCategory category = parseLineKdeLoggingCategory(data, filename);
@@ -258,7 +250,8 @@ void KDebugSettingsUtil::readLoggingCategories(const QString &filename, KdeLoggi
                             needToAppend = false;
                             break;
                         } else if (cat.categoryName == category.categoryName) {
-                            qCWarning(KDEBUGSETTINGS_LOG) << "Duplicate categories, it's a bug. Please verify: categorie:" << cat.categoryName << " filename : "<< filename;
+                            qCWarning(KDEBUGSETTINGS_LOG)
+                                << "Duplicate categories, it's a bug. Please verify: category:" << cat.categoryName << " filename : " << filename;
                             needToAppend = false;
                         }
                     }
@@ -277,8 +270,7 @@ KDebugSettingsUtil::LineLoggingQtCategory KDebugSettingsUtil::parseLineLoggingQt
 {
     LineLoggingQtCategory lineCategory;
     int equalPos = line.indexOf(QLatin1Char('='));
-    if ((equalPos != -1)
-        && (line.lastIndexOf(QLatin1Char('=')) == equalPos)) {
+    if ((equalPos != -1) && (line.lastIndexOf(QLatin1Char('=')) == equalPos)) {
         const QString pattern = line.left(equalPos);
         const QString valueStr = line.mid(equalPos + 1);
         if (valueStr == QLatin1String("true")) {
@@ -320,7 +312,7 @@ QList<KDebugSettingsUtil::LoadLoggingCategory> KDebugSettingsUtil::readLoggingQt
         qCWarning(KDEBUGSETTINGS_LOG) << "Empty file name";
         return {};
     }
-    //Code based on src/corelib/io/qloggingregistry.cpp
+    // Code based on src/corelib/io/qloggingregistry.cpp
     QFile file(filename);
     QMap<QString, KDebugSettingsUtil::LoadLoggingCategory> hashLoadLoggingCategories;
     if (file.open(QIODevice::ReadOnly)) {
@@ -347,8 +339,8 @@ QList<KDebugSettingsUtil::LoadLoggingCategory> KDebugSettingsUtil::readLoggingQt
             }
             if (rulesSections) {
                 KDebugSettingsUtil::LineLoggingQtCategory cat = parseLineLoggingQtCategory(line);
-                //qDebug() << " line " << line;
-                //qDebug() << "enable " << cat.enabled << " valid : " << cat.isValid();
+                // qDebug() << " line " << line;
+                // qDebug() << "enable " << cat.enabled << " valid : " << cat.isValid();
                 if (cat.isValid()) {
                     KDebugSettingsUtil::LoadLoggingCategory nextCat = hashLoadLoggingCategories.value(cat.logName);
                     if (nextCat.isValid()) {
@@ -384,19 +376,22 @@ QList<KDebugSettingsUtil::LoadLoggingCategory> KDebugSettingsUtil::readLoggingQt
                         nextCat.logName = cat.logName;
                         switch (cat.type) {
                         case LineLoggingQtCategory::Unknown:
-                            nextCat.loggingTypes.insert(LoadLoggingCategory::Unknown, cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
+                            nextCat.loggingTypes.insert(LoadLoggingCategory::Unknown,
+                                                        cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
                             break;
                         case LineLoggingQtCategory::Info:
                             nextCat.loggingTypes.insert(LoadLoggingCategory::Info, cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
                             break;
                         case LineLoggingQtCategory::Warning:
-                            nextCat.loggingTypes.insert(LoadLoggingCategory::Warning, cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
+                            nextCat.loggingTypes.insert(LoadLoggingCategory::Warning,
+                                                        cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
                             break;
                         case LineLoggingQtCategory::Debug:
                             nextCat.loggingTypes.insert(LoadLoggingCategory::Debug, cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
                             break;
                         case LineLoggingQtCategory::Critical:
-                            nextCat.loggingTypes.insert(LoadLoggingCategory::Critical, cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
+                            nextCat.loggingTypes.insert(LoadLoggingCategory::Critical,
+                                                        cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
                             break;
                         case LineLoggingQtCategory::All:
                             nextCat.loggingTypes.insert(LoadLoggingCategory::All, cat.enabled ? LoadLoggingCategory::Enabled : LoadLoggingCategory::Disabled);
@@ -417,7 +412,7 @@ QList<KDebugSettingsUtil::LoadLoggingCategory> KDebugSettingsUtil::readLoggingQt
 LoggingCategory::LoggingType KDebugSettingsUtil::convertCategoryTypeFromString(const QString &str)
 {
     if (str.isEmpty()) {
-        return LoggingCategory::Info; //Default
+        return LoggingCategory::Info; // Default
     } else if (str == QLatin1String("DEBUG")) {
         return LoggingCategory::Debug;
     } else if (str == QLatin1String("INFO")) {
